@@ -15,9 +15,9 @@ class color:
 
 class chop:
 	 x_coder = f"""{color.bold}
-{color.white} [⏦] - {color.cyan} 𝐋𝐈𝐁𝐑𝐀𝐑𝐘𝐒𝐇𝐀𝐃 {color.yellow} 𝐕𝐄𝐑𝐒𝐈𝐎𝐍  {color.red}1.0.5    
+{color.white} [⏦] - {color.cyan} RUBIP {color.yellow} 𝐕𝐄𝐑𝐒𝐈𝐎𝐍  {color.red}2.0.5    
 
-{color.white} [⏦] - {color.cyan} 𝐋𝐈𝐁𝐑𝐀𝐑𝐘𝐒𝐇𝐀𝐃 {color.yellow} 𝐂𝐎𝐏𝐘𝐑𝐈𝐆𝐇𝐓 (𝐂) {color.red} 2023 {color.green}𝐌𝐀𝐌𝐀𝐃 𝐂𝐎𝐃𝐄𝐑   
+{color.white} [⏦] - {color.cyan} RUBIP {color.yellow} 𝐂𝐎𝐏𝐘𝐑𝐈𝐆𝐇𝐓 (𝐂) {color.red} 2023 {color.green}𝐌𝐀𝐌𝐀𝐃 𝐂𝐎𝐃𝐄𝐑   
 
 {color.white} [⏦] - {color.cyan} 𝐃𝐄𝐕𝐄𝐋𝐎𝐏𝐄𝐑  {color.yellow} 𝐑𝐔𝐁𝐈𝐊𝐀 {color.red} 𝐂𝐇𝐀𝐍𝐍𝐄𝐋 : {color.green} @python_java_source
 
